@@ -88,6 +88,8 @@ class FSMap(MutableMapping):
         oe = on_error if on_error == "raise" else "return"
         try:
             out = self.fs.cat(keys2, on_error=oe)
+            if isinstance(out, bytes):
+                out = {keys2[0]: out}
         except self.missing_exceptions as e:
             raise KeyError from e
         out = {
@@ -176,6 +178,10 @@ class FSMap(MutableMapping):
 def maybe_convert(value):
     if isinstance(value, array.array) or hasattr(value, "__array__"):
         # bytes-like things
+        if hasattr(value, "dtype") and value.dtype.kind in "Mm":
+            # The buffer interface doesn't support datetime64/timdelta64 numpy
+            # arrays
+            value = value.view("int64")
         value = bytearray(memoryview(value))
     return value
 
